
package POS::Admin::GUI;

our $VERSION = 0.1;

sub new
{
    my $self = shift;
    my $type = ref($self) || $self;
    $self = bless {}, $type;
    return $self;
} ## end sub new
## what needs to contain:

sub initData
{
    my ($self, $imported) = @_;

    if (defined $imported) {
        #parse $imported and update internal data structures
    }
    else {
        #set defaults
    }
} ## end sub initData

#############################################
## Pure virtuals
##############
sub drawGUI
{
    my ($self, $parent);
    die 'pure virtual';
} ## end sub drawGUI

sub storeData
{
    my ($self) = @_;
    die 'pure virtual';
} ## end sub storeData

sub processEvent
{
    my ($self, $event) = @_;
    die 'pure virtual';
} ## end sub processEvent

sub checkData
{
    my ($self) = @_;
    die 'pure virtual';
} ## end sub checkData
#############################################
## EOF Pure virtuals
##############

#############################################
## GUI Helpers
##############
sub createPushButton
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createPushButton($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    return $tmp;
} ## end sub createPushButton

sub createRadioButton
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createRadioButton($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateWidgetValue($id);
    return $tmp;
} ## end sub createRadioButton

sub createInputField
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createInputField($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateWidgetValue($id);
    return $tmp;
} ## end sub createInputField

sub createMultilineEdit
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createMultiLineEdit($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateWidgetValue($id);
    return $tmp;
} ## end sub createMultilineEdit

sub createPasswordField
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createPasswordField($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateWidgetValue($id);
    return $tmp;
} ## end sub createPasswordField

sub createCheckBox
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createCheckBox($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateWidgetValue($id);
    return $tmp;
} ## end sub createCheckBox

sub createSelectionBox
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createSelectionBox($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateSelectionWidgetValue($id);
    return $tmp;
} ## end sub createSelectionBox

sub createComboBox
{
    my ($self, $parent, $id) = @_;
    my $tmp;
    $tmp = $self->{'FACTORY'}->createComboBox($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    $tmp->setNotify();
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $tmp;
    $self->updateSelectionWidgetValue($id);
    return $tmp;
} ## end sub createComboBox

sub createFrame
{
    my ($self, $parent, $id) = @_;
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $self->{'FACTORY'}->createFrame($parent, $self->{'OBJECTS'}{$id}{'LABEL'});
    return $self->{'OBJECTS'}{$id}{'WIDGET'};
} ## end sub createFrame

sub createLogView
{
    my ($self, $parent, $id) = @_;
    $self->{'OBJECTS'}{$id}{'WIDGET'} = $self->{'FACTORY'}->createLogView($parent, $self->{'OBJECTS'}{$id}{'LABEL'}, 2);
    return $self->{'OBJECTS'}{$id}{'WIDGET'};
} ## end sub createLogView
#############################################
## EOF GUI Helpers
##############

#############################################
## DATA Helpers
##############
sub setValue
{
    my ($self, $id, $data) = @_;
    $self->{'OBJECTS'}{$id}{'VALUE'} = $data;
} ## end sub setValue

sub getValue
{
    my ($self, $id, $data) = @_;
    return $self->{'OBJECTS'}{$id}{'VALUE'};
} ## end sub getValue

sub getWidget
{
    my ($self, $id) = @_;
    return $self->{'OBJECTS'}{$id}{'WIDGET'};
} ## end sub getWidget

sub getWidgetValue
{
    my ($self, $id) = @_;
    return $self->{'OBJECTS'}{$id}{'WIDGET'}->value();
} ## end sub getWidgetValue

sub updateWidgetValue
{
    my ($self, $id) = @_;
    if (defined $self->{'OBJECTS'}{$id}{'VALUE'}) {
        if (ref $self->{'OBJECTS'}{$id}{'WIDGET'} eq 'ARRAY') {
            # parse array of objects (aka OUs)
            # also VALUE are array, assign
            for (my $i = 0; $i < scalar @{ $self->{'OBJECTS'}{$id}{'WIDGET'} }; $i++) {
                if (defined $self->{'OBJECTS'}{$id}{'VALUE'}[$i]) {
                    $self->{'OBJECTS'}{$id}{'WIDGET'}[$i]->setValue($self->{'OBJECTS'}{$id}{'VALUE'}[$i]);
                }
            }
        }
        else {
            # parse single entries
            if (ref $self->{'OBJECTS'}{$id}{'VALUE'} eq 'ARRAY') {
                $self->{'OBJECTS'}{$id}{'WIDGET'}->setValue($self->{'OBJECTS'}{$id}{'VALUE'}[0]);
            }
            else {
                $self->{'OBJECTS'}{$id}{'WIDGET'}->setValue($self->{'OBJECTS'}{$id}{'VALUE'});
            }
        }
    }
} ## end sub updateWidgetValue

sub updateAllWidgetValue
{
    my ($self) = @_;
    foreach (keys(%{ $self->{'OBJECTS'} })) {
        if (defined $self->{'OBJECTS'}{$_}{'WIDGET'}) {
            if (ref($self->{'OBJECTS'}{$_}{'WIDGET'}) =~ /SelectionBox|ComboBox/) {
                $self->updateSelectionWidgetValue($_);
            }
            elsif (ref($self->{'OBJECTS'}{$_}{'WIDGET'}) =~ /PushButton|Frame/) {
                #ignore
                next;
            }
            else {
                $self->updateWidgetValue($_);
            }
        }
    }
} ## end sub updateAllWidgetValue

sub setSelection
{
    my ($self, $id, $data) = @_;
    $self->{'OBJECTS'}{$id}{'SELECTION'} = $data;
} ## end sub setSelection

sub updateSelectionWidgetSelection
{
    my ($self, $id, $item) = @_;
    if (defined $self->{'OBJECTS'}{$id}{'VALUE'}) {
        my $selBox = $self->{'OBJECTS'}{$id}{'WIDGET'};
        my $it     = $selBox->findItem($item);
        if (defined $it) {
            $selBox->selectItem($it);
        }
    }
} ## end sub updateSelectionWidgetSelection

sub updateSelectionWidgetValue
{
    my ($self, $id) = @_;
    if (defined $self->{'OBJECTS'}{$id}{'VALUE'}) {
        my @data = @{ $self->{'OBJECTS'}{$id}{'VALUE'} };
        $self->{'OBJECTS'}{$id}{'WIDGET'}->deleteAllItems();
        for (my $i = 0; $i < scalar @data; $i++) {
            $self->{'OBJECTS'}{$id}{'WIDGET'}->addItem($data[$i]);
        }
    }
    if (defined $self->{'OBJECTS'}{$id}{'SELECTION'}) {
        $self->updateSelectionWidgetSelection($id, $self->{'OBJECTS'}{$id}{'SELECTION'});
    }
} ## end sub updateSelectionWidgetValue

sub storeAllWidgetValue
{
    my ($self) = @_;
    foreach (keys(%{ $self->{'OBJECTS'} })) {
        if (defined $self->{'OBJECTS'}{$_}{'WIDGET'}) {
            if (ref $self->{'OBJECTS'}{$_}{'WIDGET'} eq 'ARRAY') {
                my @data = ();
                for (my $i = 0; $i < scalar @{ $self->{'OBJECTS'}{$_}{'WIDGET'} }; $i++) {
                    $data[$i] = $self->{'OBJECTS'}{$_}{'WIDGET'}[$i]->value();
                }
                $self->{'OBJECTS'}{$_}{'VALUE'} = \@data;
            }
            elsif (ref($self->{'OBJECTS'}{$_}{'WIDGET'}) =~ /Frame|SelectionBox|ComboBox|PushButton|LogView/) {
                #ignore
            }
            else {
                $self->{'OBJECTS'}{$_}{'VALUE'} = $self->{'OBJECTS'}{$_}{'WIDGET'}->value();
            }
        }
    }
} ## end sub storeAllWidgetValue
#############################################
## EOF DATA Helpers
##############

#############################################
## Popup Helpers
##############
sub yesnoPopup
{
    my ($self, $msg) = @_;
    return $self->popup('yesno', $msg);
} ## end sub yesnoPopup

sub okPopup
{
    my ($self, $msg) = @_;
    return $self->popup('ok', $msg);
} ## end sub okPopup

sub popup
{
    my ($self, $type, $msg) = @_;
    my $factory = $self->{'FACTORY'};
    my $dlg     = $factory->createPopupDialog();
    my $vbox    = $factory->createVBox($dlg);
    $factory->createLabel($vbox, $msg);
    if ($type eq 'ok') {
        my $btn = $factory->createPushButton($vbox, 'Ok');
        $dlg->setDefaultButton($btn);
    }
    elsif ($type eq 'yesno') {
        my $hbox = $factory->createHBox($vbox);
        my $okbtn = $factory->createPushButton($hbox, 'Yes');
        $factory->createPushButton($hbox, 'No');
        $dlg->setDefaultButton($okbtn);
    }
    else {
        die 'not supported';
    }
    my $event  = $dlg->waitForEvent();
    my $result = 0;
    if ($event->widget() == $dlg->defaultButton()) {
        $result = 1;
    }
    $dlg->destroy();
    return $result;
} ## end sub popup
#############################################
## EOF Popup Helpers
##############

1;
