package POS::Admin::GUI::FIN;

use strict;

# GUI common, includes yui
use base 'POS::Admin::GUI';
our @ISA = qw(POS::Admin::GUI);
# Data interface
use POS::Admin::GUI::Data;
use POSIX qw( _exit );

our $VERSION = 0.1;

my %objects = (
    # IM
    # config templates
    LOG_STATUS       => { LABEL => 'Operations ouput' },
    CHCK_GENERATEOIF => { LABEL => 'Create Offline Initialization File after LDAP is updated' },
    BTN_UPDATEADMIN  => { LABEL => 'Update LDAP database' },
    BTN_GENERATECONF => { LABEL => 'Create XML configuration' }
);

sub new
{
    my $self = shift;
    my $type = ref($self) || $self;
    $self = bless {}, $type;
    $self->{'OBJECTS'}    = \%objects;
    $self->{'FACTORY'}    = shift;
    $self->{'OPTFACTORY'} = shift;
    $self->{'ENV'}        = shift;
    $self->{'IMPORT'}     = 0;
    return $self;
} ## end sub new

sub initData
{
    my ($self, $data) = @_;
    $self->{'DATA'} = $data;
} ## end sub initData

sub drawGUI
{
    my ($self, $replacePoint) = @_;
    my $factory  = $self->{'FACTORY'};
    my $frameBox = $factory->createVBox($replacePoint);
    $frameBox->setWeight(0, 100);
    $frameBox->setWeight(1, 100);
    my $btnBoxes = $factory->createVBox($frameBox);
    $btnBoxes->setWeight(0, 100);
    $self->{'BUTTONS'} = $btnBoxes;
    my $commitBox = $factory->createVBox($factory->createFrame($btnBoxes, 'LDAP update'));
    my $btnCommit = $self->createPushButton($factory->createLeft($commitBox), qw(BTN_UPDATEADMIN));
    my $checkOIF = $self->createCheckBox($factory->createLeft($commitBox), qw(CHCK_GENERATEOIF));

    if ($self->{'DATA'}{ONADMIN} == 0) {
        $checkOIF->setEnabled(0);
        $btnCommit->setEnabled(0);
        $factory->createLabel($factory->createLeft($commitBox), '*available only on AdminServer')->setEnabled(0);
    }
    my $xmlBox = $factory->createVBox($factory->createFrame($btnBoxes, 'XML export'));
    $self->createPushButton($factory->createLeft($xmlBox), qw(BTN_GENERATECONF));
    my $outputEdit = $factory->createFrame($btnBoxes, 'Output log');
    $outputEdit = $self->createLogView($outputEdit, qw(LOG_STATUS));
    $outputEdit->setStretchable($yui::YD_HORIZ, 1);
    $outputEdit->setStretchable($yui::YD_VERT,  1);
} ## end sub drawGUI

sub processEvent
{
    my ($self, $event) = @_;
    unless (defined $event) {
        $self->processImport();
        return;
    }
    my $widget = $event->widget();
    if ($widget == $self->getWidget(qw(BTN_GENERATECONF))) {
        my $app = yui::YUI::application();
        my $filename = $app->askForSaveFileName('slepos_XML.xml', 'SLEPOS XML data', 'Choose SLEPOS XML filename');
        return if (not $filename);
        $self->{'DATA'}->exportXML($filename);
        $self->appendLog("Created SLEPOS XML $filename");
        return;
    }
    elsif ($widget == $self->getWidget(qw(BTN_UPDATEADMIN))) {
        my $app = yui::YUI::application();
        $self->appendLog("Validating and updating LDAP. Please wait...");
        $app->busyCursor();
        $self->{'BUTTONS'}->setChildrenEnabled(0);
        $self->{'IMPORT'} = 1;
        return;
    }

} ## end sub processEvent

sub processImport
{
    my ($self) = @_;
    if ($self->{'IMPORT'} == 1) {
        my ($fh, $logfile) = tempfile();
        close($fh);
        open(STDERR, '>', $logfile);
        require POS::Admin::ldapConfig;
        use File::Temp qw(tempfile);
        my $config = new POS::Config("/etc/SLEPOS/adminserver.conf");
        ($fh, my $filename) = tempfile();
        close($fh);
        $self->{'DATA'}->exportXML($filename);
        my $ldapConfig = POS::Admin::ldapConfig->new(CONFIG => $config, OPTIONS => { 'file' => $filename });
        $self->{'RESULT'} = $ldapConfig->importXML();
        unlink $filename;
        $self->appendLog($self->readLogFromFile($logfile));

        unless (defined $self->{'RESULT'}) {
            $self->appendLog('Import to LDAP failed! Try manual import.');
            $self->okPopup('Import to LDAP failed! Try manual import');
        }
        else {
            $self->appendLog('Import to LDAP successful.');
            # generate OIF if requested
            if ($self->getWidgetValue(qw(CHCK_GENERATEOIF))) {
                my $bsinfo = $self->{'DATA'}->getBranchServer();
                my $dn =
                  'cn=' . $bsinfo->{'LOCATION'}{'scLocation'} . ',ou=' .
                  join(',ou=', @{ $bsinfo->{'organizationalUnit'} }) . ',o=' . $bsinfo->{'organization'} . ',c=' .
                  $bsinfo->{'country'};
                open(STDOUT, '>', $logfile);
                my $res = $ldapConfig->queryGenerate({ 'base' => $dn });
                close(STDOUT);
                $self->appendLog($self->readLogFromFile($logfile));
                unless ($res == 0) {
                    $self->appendLog('OIF creation failed!');
                    $self->okPopup('OIF creation failed!');
                }
            }
        }
        # restore UI
        $self->{'BUTTONS'}->setChildrenEnabled(1);
        my $app = yui::YUI::application();
        $app->normalCursor();
        $self->{'IMPORT'} = 0;
    }
} ## end sub processImport

sub appendLog
{
    my ($self, $line) = @_;
    return unless ($line);
    my $prop = yui::YPropertyValue->new($line);
    $self->{'OBJECTS'}{'LOG_STATUS'}{'WIDGET'}->setProperty($yui::YUIProperty_LastLine, $prop);
} ## end sub appendLog

sub readLogFromFile
{
    my ($self, $file) = @_;
    my $fh;
    open($fh, '<', $file);
    my $log;
    while (<$fh>) {
        $log .= $_;
    }
    return $log;
} ## end sub readLogFromFile

1;
