# BranchServer image configuration logic for SLEPOS-GUI
package POS::Admin::GUI::IM;

use strict;
use warnings;

# GUI common, includes yui
use base 'POS::Admin::GUI';
our @ISA = qw(POS::Admin::GUI);
# Data interface
use POS::Admin::GUI::Data;
use POS::Admin::GUI::FT;

our $VERSION = 0.1;

my %objects = (
    # IM
    ## global
    EDIT_NAME       => { LABEL => 'I&mage name',                   WIDGET => undef, VALUE => undef },
    EDIT_VERSION    => { LABEL => 'Im&age version',                WIDGET => undef, VALUE => undef },
    EDIT_FILENAME   => { LABEL => 'Image fi&le',                   WIDGET => undef, VALUE => undef },
    EDIT_PASSWORD   => { LABEL => 'Image password' },
    RADIO_GLOBAL    => { LABEL => '&Global image',                 WIDGET => undef, VALUE => undef },
    RADIO_LOCAL     => { LABEL => 'BranchServer l&ocal image',     WIDGET => undef, VALUE => undef },
    SEL_LIST        => { LABEL => 'Regis&tered images',            WIDGET => undef, VALUE => undef },
    EDIT_DHCPREMOTE => { LABEL => 'D&HCP Options for remote Boot', WIDGET => undef, VALUE => undef },
    EDIT_DHCPLOCAL  => { LABEL => 'DHC&P Options for local Boot',  WIDGET => undef, VALUE => undef },
    EDIT_BSIZE =>
      { LABEL => 'Bloc&ksize depended of the file size, 1024, 2048,4096, 8192', WIDGET => undef, VALUE => undef },
    BTN_ADDIMAGE    => { LABEL => 'Add image',                 LABEL1 => 'Update image' },
    BTN_REMOVEIMAGE => { LABEL => 'Remove image from list',    WIDGET => undef, VALUE => undef },
    SEL_NEW         => { LABEL => '<add new image>',           WIDGET => undef, VALUE => undef },
    GLOBAL          => { LABEL => 'Basic image configuration', WIDGET => undef, VALUE => undef },
    BTN_FILENAME    => { LABEL => 'S&elect File',              WIDGET => undef, VALUE => undef }
);

my $imageNameAlreadyExists = 'Image with this name already exists. Cannot rename';
my $changesExist           = 'Unsaved changes exist, selecting another image will reset them. Continue?';

sub new
{
    my $self = shift;
    my $type = ref($self) || $self;
    $self = bless {}, $type;
    $self->{'OBJECTS'}    = \%objects;
    $self->{'FACTORY'}    = shift;
    $self->{'OPTFACTORY'} = shift;
    $self->{'ENV'}        = shift;
    $self->{'DATA'}       = ();
    $self->{'DIRTY'}      = 0;
    # init filetemplate minimodule
    $self->{'FT'} = POS::Admin::GUI::FT->new($self->{'FACTORY'}, $self->{'OPTFACTORY'}, $self->{'ENV'});
    return $self;
} ## end sub new
## what needs to contain:

sub initData
{
    my ($self, $data) = @_;
    $self->{'DATA'} = $data;
    # FIXME: when frontent is updated to support multiple BSs, update this
    my $bslist = $self->{'DATA'}->getBranchServerList();
    $self->{'BRANCHDN'} = $bslist->[0];

    my %images = ();
    $images{ $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'} } = {
        NAME       => '',
        FILENAME   => '',
        VERSIONS   => { '' => { 'scPassword' => '', 'scDisabled' => 'TRUE' } },
        GLOBAL     => 1,
        BSIZE      => '8192',
        DHCPLOCAL  => 'LOCALBOOT',
        DHCPREMOTE => '/boot/pxelinux.0',
        TEMPLATES  => {}
    };
    # set defaults
    my $iminfo = $self->{'DATA'}->getImages($self->{'BRANCHDN'});
    my $images = [$self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'}];
    foreach my $image (keys %$iminfo) {
        $images{$image} = {
            GLOBAL => $iminfo->{$image}{'ROLE'} eq 'global' ? 1 : 0,
            VERSION    => $iminfo->{$image}{'scPosImageVersion'},
            DHCPREMOTE => $iminfo->{$image}{'scDhcpOptionsRemote'},
            DHCPLOCAL  => $iminfo->{$image}{'scDhcpOptionsLocal'},
            FILENAME   => $iminfo->{$image}{'scImageFile'},
            BSIZE      => $iminfo->{$image}{'scBsize'},
            NAME       => $iminfo->{$image}{'scImageName'},
            TEMPLATES  => $iminfo->{$image}{'TEMPLATES'},
            VERSIONS   => $iminfo->{$image}{'VERSIONS'},
            DN         => $iminfo->{$image}{'DN'}
        };
        push @$images, $image;
    }
    $self->{'IMAGES'} = \%images;
    $self->setValue(qw(SEL_LIST), $images);
    $self->{'FT'}->initData($data);
    $self->{'SELECTION'} = $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'};
} ## end sub initData

sub drawGUI
{
    my ($self, $parent) = @_;
    # undef all widget values - needed for value autosave
    foreach (keys %{ $self->{'OBJECTS'} }) {
        undef $self->{'OBJECTS'}{$_}{'WIDGET'};
    }
    # check state
    if ($self->{'ENV'}{STATE} eq 'IMft') {
        return $self->{'FT'}->drawGUI($parent);
    }

    # draw
    my $factory  = $self->{'FACTORY'};
    my $frameBox = $factory->createVBox($parent);
    $frameBox = $factory->createHBox($frameBox);
    my $selBoxIM = $self->createSelectionBox($frameBox, qw(SEL_LIST));
    $selBoxIM->setWeight(0, 33);
    $selBoxIM->setWeight(1, 100);
    $factory->createHSpacing($frameBox);
    my $right = $factory->createVBox($frameBox);
    $right->setWeight(0, 66);
    $right->setWeight(1, 100);
    $factory->createVSpacing($right);
    ## basic IM config
    my $basicIM = $self->createFrame($right, qw(GLOBAL));
    $basicIM = $factory->createVBox($basicIM);
    my $radios = $factory->createRadioButtonGroup($basicIM);
    $radios = $factory->createVBox($radios);
    my $radioGlobal = $factory->createLeft($radios);
    $radioGlobal = $self->createRadioButton($radioGlobal, qw(RADIO_GLOBAL));
    my $radioLocal = $factory->createLeft($radios);
    $radioLocal = $self->createRadioButton($radioLocal, qw(RADIO_LOCAL));
    my $editImName = $factory->createLeft($basicIM);
    $editImName = $self->createInputField($editImName, qw(EDIT_NAME));
    $editImName->setStretchable(0, 1);
    my $editImVersion = $factory->createLeft($basicIM);
    $editImVersion = $self->createInputField($editImVersion, qw(EDIT_VERSION));
    my $tmp = $factory->createHBox($basicIM);
    my $editImFileName = $self->createInputField($tmp, qw(EDIT_FILENAME));
    $editImFileName->setStretchable(0, 1);
    my $btnImSelectFile = $self->createPushButton($tmp, qw(BTN_FILENAME));
    $factory->createHStretch($tmp);

    if ($self->{'ENV'}{ADVANCED} == 1) {
        my $editBSPass = $self->createPasswordField($basicIM, qw(EDIT_PASSWORD));
        $editBSPass->setStretchable(0, 1);
        my $editImDhcpRemote = $self->createInputField($basicIM, qw(EDIT_DHCPREMOTE));
        $editImDhcpRemote->setStretchable(0, 1);
        my $editImDhcpLocal = $self->createInputField($basicIM, qw(EDIT_DHCPLOCAL));
        $editImDhcpLocal->setStretchable(0, 1);
        my $editImBsize = $self->createInputField($basicIM, qw(EDIT_BSIZE));
        $editImBsize->setStretchable(0, 1);
    }
    ## configuration templates
    $self->{'FT'}->drawEmbedded($basicIM);
    ## rest
    $factory->createVStretch($right);
    $tmp = $factory->createHBox($right);
    $self->createPushButton($tmp, qw(BTN_ADDIMAGE));
    $self->createPushButton($tmp, qw(BTN_REMOVEIMAGE));
    #set previously selected image
    $self->selectImage();
} ## end sub drawGUI

sub storeData
{
    my ($self, $data) = @_;
    # store values from widget to internal struct
    $self->storeAllWidgetValue() if ($self->{'ENV'}{'STATE'} eq 'IM');
    my $iminfo = {};
    foreach my $image (keys %{ $self->{'IMAGES'} }) {
        next if ($image eq $self->{'OBJECTS'}{SEL_NEW}{'LABEL'});
        $iminfo->{$image} = {
            ROLE => $self->{'IMAGES'}{$image}{'GLOBAL'} ? 'global' : 'local',
            scImageName         => $self->{'IMAGES'}{$image}{'NAME'},
            scDhcpOptionsRemote => $self->{'IMAGES'}{$image}{'DHCPREMOTE'},
            scDhcpOptionsLocal  => $self->{'IMAGES'}{$image}{'DHCPLOCAL'},
            scImageFile         => $self->{'IMAGES'}{$image}{'FILENAME'},
            scBsize             => $self->{'IMAGES'}{$image}{'BSIZE'},
            TEMPLATES           => $self->{'IMAGES'}{$image}{'TEMPLATES'},
            VERSIONS            => $self->{'IMAGES'}{$image}{'VERSIONS'},
            DN                  => $self->{'IMAGES'}{$image}{'DN'}
        };
    }
    $data->updateImages($iminfo, $self->{'BRANCHDN'});
    return 1;
} ## end sub storeData

sub selectImage
{
    my ($self) = @_;
    my $name = $self->{'SELECTION'};
    if ($name eq $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'}) {
        $self->getWidget(qw(BTN_ADDIMAGE))->setLabel($self->{'OBJECTS'}{'BTN_ADDIMAGE'}{'LABEL'});
    }
    else {
        $self->getWidget(qw(BTN_ADDIMAGE))->setLabel($self->{'OBJECTS'}{'BTN_ADDIMAGE'}{'LABEL1'});
    }
    if (not $self->{'DIRTY'}) {
        if (not $self->getWidget(qw(SEL_LIST))->findItem($name)) {
            #image is in process being added, load <new image> data
            $name = $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'};
        }
        $self->setValue(qw(EDIT_NAME),     $self->{'IMAGES'}{$name}{'NAME'});
        $self->setValue(qw(EDIT_FILENAME), $self->{'IMAGES'}{$name}{'FILENAME'});
        # get first version from versions, for now multiversion is not supported
        my ($version, $data) = %{ $self->{'IMAGES'}{$name}{'VERSIONS'} };
        $self->setValue(qw(EDIT_VERSION),    $version);
        $self->setValue(qw(EDIT_PASSWORD),   $data->{'scPassword'} || '');
        $self->setValue(qw(RADIO_GLOBAL),    $self->{'IMAGES'}{$name}{'GLOBAL'} ? 1 : 0);
        $self->setValue(qw(RADIO_LOCAL),     $self->{'IMAGES'}{$name}{'GLOBAL'} ? 0 : 1);
        $self->setValue(qw(EDIT_BSIZE),      $self->{'IMAGES'}{$name}{'BSIZE'});
        $self->setValue(qw(EDIT_DHCPLOCAL),  $self->{'IMAGES'}{$name}{'DHCPLOCAL'});
        $self->setValue(qw(EDIT_DHCPREMOTE), $self->{'IMAGES'}{$name}{'DHCPREMOTE'});
        $self->updateAllWidgetValue();
        $self->{'FT'}->updateData($self->{'IMAGES'}{$name}{'TEMPLATES'});
    }
    my $selBox = $self->getWidget(qw(SEL_LIST));
    if (defined $selBox) {
        $selBox->selectItem($selBox->findItem($name));
    }
} ## end sub selectImage

sub processEvent
{
    my ($self, $event) = @_;
    $self->storeAllWidgetValue();
    my $widget = $event->widget();
    if ($self->{'ENV'}{STATE} eq 'IM') {
        ## Add image
        if ($widget == $self->getWidget(qw(BTN_ADDIMAGE))) {
            if ($self->{'DIRTY'}) {
                $self->{'DIRTY'} = 0;
            }
            else {
                # no change, we can ignore that
                return;
            }
            # add new image to SELLIST, select it, store data to internal datastruct
            my $selBox = $self->getWidget(qw(SEL_LIST));
            # get selected item in selection widget
            my $selectedItem = $self->{'SELECTION'};
            # get name filled in service name input
            my $imageName = $self->getWidgetValue(qw(EDIT_NAME));
            # check name
            return if (not $imageName);
            my $version  = $self->getWidgetValue(qw(EDIT_VERSION));
            my $locality = $self->getWidgetValue(qw(RADIO_LOCAL)) ? 'local' : 'global';
            my $imageId  = "${imageName};${locality}";
            # templates tmpvar
            my $templates;
            if ($selectedItem ne $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'}) {
                $templates = $self->{'IMAGES'}{$selectedItem}{'TEMPLATES'};
                if ($selectedItem ne $imageId) {
                    #name changed, check uniqueness
                    if (defined $self->{'IMAGES'}{$imageId}) {
                        $self->okPopup($imageNameAlreadyExists);
                        return;
                    }
                    #preserve DN to track movement
                    $self->{'IMAGES'}{$imageId}{'DN'} = $self->{'IMAGES'}{$selectedItem}{'DN'};
                    #rename, delete old name
                    delete $self->{'IMAGES'}{$selectedItem};
                    my $list = $self->getValue(qw(SEL_LIST));
                    for (my $i = 0; $i < scalar @$list; $i++) {
                        if ($list->[$i] eq $selectedItem) {
                            $list->[$i] = $imageId;
                            last;
                        }
                    }
                    $self->setValue(qw(SEL_LIST), $list);
                }
            }
            else {
                # adding new
                #check if unique
                if (defined $self->{'IMAGES'}{$imageId}) {
                    $self->okPopup($imageNameAlreadyExists);
                    return;
                }
                my $list = $self->getValue(qw(SEL_LIST));
                push @$list, $imageId;
                $self->setValue(qw(SEL_LIST), $list);
                # newly created images may have templates in <add new template> hash, get it and clear orig.
                $templates = $self->{'IMAGES'}{ $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'} }{'TEMPLATES'};
                $self->{'IMAGES'}{ $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'} }{'TEMPLATES'} = {};
            }
            # get advanced data
            my ($password, $dhcplocal, $dhcpremote, $bsize);
            if ($self->{'ENV'}{ADVANCED}) {
                $password   = $self->getWidgetValue(qw(EDIT_PASSWORD));
                $dhcplocal  = $self->getWidgetValue(qw(EDIT_DHCPLOCAL));
                $dhcpremote = $self->getWidgetValue(qw(EDIT_DHCPREMOTE));
                $bsize      = $self->getWidgetValue(qw(EDIT_BSIZE));
            }
            else {
                $password   = $self->getValue(qw(EDIT_PASSWORD));
                $dhcplocal  = $self->getValue(qw(EDIT_DHCPLOCAL));
                $dhcpremote = $self->getValue(qw(EDIT_DHCPREMOTE));
                $bsize      = $self->getValue(qw(EDIT_BSIZE));
            }
            # add new data (when either adding new or renaming)
            $self->{'IMAGES'}{$imageId} = {
                NAME       => $imageName,
                FILENAME   => $self->getWidgetValue(qw(EDIT_FILENAME)),
                VERSION    => $version,
                BSIZE      => $bsize,
                DHCPLOCAL  => $dhcplocal,
                DHCPREMOTE => $dhcpremote,
                GLOBAL     => $self->getWidgetValue(qw(RADIO_GLOBAL)),
                TEMPLATES  => $templates,
                VERSIONS   => { $version => { 'scDisabled' => 'FALSE', 'scPassword' => $password } }
            };
            # update selList
            $self->updateSelectionWidgetValue(qw(SEL_LIST));
            $self->{'SELECTION'} = $imageId;
            $self->selectImage();
        }
        ## Remove image
        elsif ($widget == $self->getWidget(qw(BTN_REMOVEIMAGE))) {
            my $selBox = $self->getWidget(qw(SEL_LIST));
            # get selected item in selection widgetff
            my $selectedItem = $self->{'SELECTION'};
            if ($selectedItem ne $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'}) {
                delete $self->{'IMAGES'}{$selectedItem};
                my @list = grep (!/$selectedItem/, @{ $self->getValue(qw(SEL_LIST)) });
                $self->setValue(qw(SEL_LIST), [sort @list]);
                $self->{'SELECTION'} = $self->{'OBJECTS'}{'SEL_NEW'}{'LABEL'};
                $self->selectImage();
            }
        }
        ## select image
        elsif ($widget == $self->getWidget(qw(SEL_LIST))) {
            if ($self->{'DIRTY'}) {
                if ($self->yesnoPopup($changesExist)) {
                    $self->{'DIRTY'} = 0;
                }
                else {
                    return;
                }
            }
            $self->{'SELECTION'} = $self->getWidget(qw(SEL_LIST))->selectedItem()->label();
            $self->selectImage();
        }
        ## image file
        elsif ($widget == $self->getWidget(qw(BTN_FILENAME))) {
            my $app = yui::YUI::application();
            my $filename = $app->askForExistingFile('SLEPOS Image file', '*', 'Select SLEPOS Image file');
            # cancel hit
            return unless ($filename);
            # get only filename instead of full path
            ($filename) = $filename =~ /.*\/([^\/]*)$/;
            $self->setValue(qw(EDIT_FILENAME), $filename);
            $self->updateWidgetValue(qw(EDIT_FILENAME));
        }
        # IM FT buttons
        else {
            $self->{'DIRTY'} = 1;
            $self->{'FT'}->processEvent($event);
        }
    }
    elsif ($self->{'ENV'}{STATE} eq 'IMft') {
        # process file templates events
        $self->{'FT'}->processEvent($event);
    }
} ## end sub processEvent
