#!/usr/bin/perl -w
package POS::Config;

use strict;
use warnings;
use POS::Syslog;

our $VERSION = '1.0';

# define constants
### do not change this - all scripts depend on it
### when paths really must be changed, change them in posInit* scripts and posAdmin.pl
### (default value used implicitly to minimize hardcoded pathes)
my $DEFAULT_BRANCHCONFIGFILE = "/etc/SLEPOS/branchserver.conf";
### when path to default admin config file, posAdmin.pl has to be changed as well
my $DEFAULT_ADMINCONFIGFILE = "/etc/SLEPOS/adminserver.conf";
# default password key file - when changed, posInitAdminserver.sh need to be changed as well
my $DEFAULT_PASS_FILE = "/etc/SLEPOS/salt.key";
my $DEFAULTS_FILE     = "/usr/lib/SLEPOS/defaults";

# constructor
sub new
{
    my $package = shift;
    my @files   = @_;
    my $data    = {};
    if ($#files == -1) {
        if (-e $DEFAULT_ADMINCONFIGFILE) {
            push @files, $DEFAULT_ADMINCONFIGFILE;
        }
        if (-e $DEFAULT_BRANCHCONFIGFILE) {
            push @files, $DEFAULT_BRANCHCONFIGFILE;
        }
        if ($#files == -1) {
            die('No config file loaded!');
        }
    }

    # Check for installed services - does not mean that proper configuration files are loaded/parsed
    if (-e $DEFAULT_ADMINCONFIGFILE) {
        # AdminServer is installed
        $data->{'POS_ADMIN_DEPLOYED'} = "yes";
    }
    if (-e $DEFAULT_BRANCHCONFIGFILE) {
        # BranchServer is installed
        $data->{'POS_BRANCH_DEPLOYED'} = "yes";
    }
    @files = ($DEFAULTS_FILE, @files);

    foreach my $file (@files) {
        if ($file eq 'admin') {
            $file = $DEFAULT_ADMINCONFIGFILE;
        }
        elsif ($file eq 'branchadmin' || $file eq 'branchservice') {
            $file = $DEFAULT_BRANCHCONFIGFILE;
        }
        my $fh;
        if (!open($fh, '<', $file)) {
            die("Can't read config file $file");
        }
        while (<$fh>) {
            chomp;
            if (/^#/) {
                next;
            }
            if ($_ =~ /=/g) {
                ## FIXME: should be unified with function readValue() in posInitLdap.sh
                ##        difference: 'key = "some value"', after second '"' should be text ignored
                ## splitting in 2 fields at maximum
                my ($option, $value) = split(/=/, $_, 2);
                $option =~ s/^\s+//g;
                $option =~ s/\s+$//g;
                $option =~ s/\"+//g;
                $value  =~ s/^\s+//g;
                $value  =~ s/\s+$//g;
                $value  =~ s/^\"(.*)\"\s*$/$1/;
                $value  =~ s/\\\$/\$/g;

                if ($option and $value) {
                    if ($option =~ /POS_ADMIN_PASSWORD|LEASES2LDAP_ADMIN_PW|POS_SM_PASSWORD/) {
                        #decode password
                        if (not -f $DEFAULT_PASS_FILE) {
                            log_warn_print('Encryption key file does not exist. Password loaded as plaintext.');
                            $data->{$option} = $value;
                            next;
                        }
                        #decode
                        $data->{$option} =
`echo -n $value | base64 -d -w0 2>/dev/null | openssl enc -aes128 -d -kfile $DEFAULT_PASS_FILE 2>/dev/null`;
                        if ($? != 0) {
                           #we have decoding error or password is not encoded -> to be compatible with previous versions
                            log_warn_print('Password decoding failed, Loaded as plaintext.');
                            $data->{$option} = $value;
                        }
                        chomp($data->{$option});
                    }
                    else {
                        if (defined $data->{$option}) {
                            if ($data->{$option} ne $value) {
                                log_info_printf('Common entry "%s" value taken from %s',
                                    $option, $DEFAULT_BRANCHCONFIGFILE);
                            }
                        }
                        $data->{$option} = $value;
                    }
                }
            }
        }
        close($fh);
    }
    return bless($data, $package);
} ## end sub new

1;
