#!/usr/bin/perl -w
package POS::DhcpEntries;

use strict;
use POS::Syslog;

our $VERSION = 0.1;


require Exporter;
our @ISA = qw(Exporter);

our @EXPORT = qw(lease starts ends ethernet hostname );

our @EXPORT_OK = qw(read_dhcp_leases);


## fallback-filename for dhcpd.leases path

my $DEFAULT_DHCP_LOG  = "/var/dhcp/dhcpd.leases";
my $DEFAULT_DHCP_CONF = "/etc/SLEPOS/dhcpd/dhcpd.conf";

sub new
{
    my $package = shift;
    my $self    = {
        #init data
        'STATIC' => undef,    ## config data
        'CACHE'  => undef,    ## cached ldap data
    };

    %$self = (%$self, @_);

    #return if !defined $self->{'STATIC'};
    #return if !defined $self->{'CACHE'};

    return bless($self);
} ## end sub new


sub testIP
{
    my $ip_addr = shift;
    require POS::IP;
    my $ip = POS::IP->new($ip_addr);
    if (!$ip) {
        return 0;
    }
    return 1;
} ## end sub testIP


sub testMAC
{
    my $mac_addr = shift;
    require POS::MAC;
    my $mac = POS::MAC->new('MAC' => $mac_addr);
    if (!defined $mac) {
        return 0;
    }
    return 1;
} ## end sub testMAC


sub read_dhcp_leases
{
    my ($self, $filename) = @_;
    if (!$filename) {
        $filename = $DEFAULT_DHCP_LOG;
    }
    my %entry_hash;

    open(FH, $filename) or return (undef);
    my $ip           = undef;
    my $mac          = undef;
    my $starts       = undef;
    my $ends         = undef;
    my $hostname     = undef;
    my $begin        = undef;
    my $is_tokenring = 0;       #probably good idea to deprecate...

    while (<FH>) {
        ## excluding comments
        if ($_ =~ /^[#]/) {
            next;
        }
        if (!$begin) {
            if (/\{/) {
                require POS::IP;
                my @list = split(/\s+/, $_);
                my $i = undef;
                foreach $i (@list) {
                    $ip = POS::IP->new($i);
                    if ($ip) {
                        #log_debug_printf('found ip %s in dhcp.leases file.',$ip->get_ip());
                        $begin = 1;
                        last;
                    }
                }
                #	print "returned ip:  " . $ip->get_ip() . "\n";
            }
            else {
                next;
            }
        }
        elsif (/starts/) {
            my @list = split(/[\s;]+/, $_);
            if (@list >= 3) {
                $starts = $list[@list - 2] . " " . $list[@list - 1];
            }
        }
        elsif (/ends/) {
            my @list = split(/[\s;]+/, $_);
            if (@list >= 3) {
                $ends = $list[@list - 2] . " " . $list[@list - 1];
            }
        }
        elsif (/ethernet/) {
            require POS::MAC;
            my @list = split(/[\s;]/x, $_);
            my $i = undef;
            #      print scalar @list . "\n";
            foreach $i (@list) {
                #	print "listvalue: $i   = ($_)\n";
                $mac = POS::MAC->new('MAC' => $i);
                if (defined $mac) {
                    #log_debug_printf(' for %s ',uc($mac->get_mac()));
                    last;
                }
            }
        }
        elsif (/token-ring/) {
            require POS::MAC;
            my @list = split(/[\s;]/x, $_);
            my $i = undef;
            #      print scalar @list . "\n";
            foreach $i (@list) {
                #	print "listvalue: $i   = ($_)\n";
                $mac = POS::MAC->new('MAC' => $i);
                if (defined $mac) {
                    $is_tokenring = 1;
                    last;
                }
            }
        }
        elsif (/hostname/) {
            my @list = split(/[\s;\"]+/, $_);
            if (@list >= 2) {
                $hostname = $list[@list - 1];
            }
        }
        elsif (/\}/) {
            if ($mac && $ip && $ip->get_ip() && $mac->get_mac()) {
                my %entry = (
                    lease       => $ip->get_ip(),
                    ethernet    => $mac->get_mac(),
                    starts      => $starts,
                    ends        => $ends,
                    hostname    => $hostname,
                    istokenring => $is_tokenring
                );
                log_debug_printf('found ip %s for %s in dhcp.leases file.', $ip->get_ip(), $mac->get_mac());
                $entry_hash{ uc($mac->get_mac()) } = \%entry;    #MAC keys must be upcase
            }
            $begin        = undef;
            $ip           = undef;
            $mac          = undef;
            $starts       = undef;
            $ends         = undef;
            $hostname     = undef;
            $is_tokenring = 0;
        }
    }
    return (\%entry_hash);
} ## end sub read_dhcp_leases


#read all workstation entris form dhcp confguration
sub read_dhcp_config
{
    my ($self, $filename) = @_;
    if (!$filename) {
        $filename = $DEFAULT_DHCP_CONF;
    }
    my %entry_hash_host;
    open(FH, $filename) or return (undef);
    my $pgs    = $self->{'STATIC'}{'CONFIG'}{'POS_DHCP_GROUP_START_ID'};
    my $pge    = $self->{'STATIC'}{'CONFIG'}{'POS_DHCP_GROUP_END_ID'};
    my $status = 0;
    my $host;
    while (<FH>) {
        $status = 1 if $_ =~ /^$pgs/;
        last if $_ =~ /^$pge/;
        if ($status) {    #read workstations
            if ($_ =~ /^\s*host\s*(.*)\s*{/) {    #host CR06-001125A7D61F.lhb.sleposlab-test.test74.mq{
                $host = $1;
            }
            if ($_ =~ /^\s*hardware\s*ethernet\s*(.*)\s*;/) {
                $entry_hash_host{$host}{'MAC'} = $1;
            }
            if ($_ =~ /^\s*fixed-address\s*(.*)\s*;/) {
                $entry_hash_host{$host}{'IP'} = $1;
            }
            #next server, filename?
        }

    }
    my %entry_hash;
    #rehash by MAC:
    foreach my $key (keys %entry_hash_host) {
        my $mac = uc($entry_hash_host{$key}{'MAC'});
        $entry_hash{$mac}{'host'} = $key;
        $entry_hash{$mac}{'MAC'}  = $mac;
        $entry_hash{$mac}{'IP'}   = $entry_hash_host{$key}{'IP'};
    }
    return (\%entry_hash);


} ## end sub read_dhcp_config


1;
