#!/usr/bin/perl -w
## @file
# Implementation of POS::MAC


## @class
# MAC adress utils
package POS::MAC;

use strict;

our $VERSION = 0.1;


require Exporter;
our @ISA    = qw(Exporter);
our @EXPORT = qw( MAC get_mac);


# TODO do not parse, just init basic data, no need for input of MAC -> change code in posDnsDhcp.pm
## @cmethod object new($mac)
# Create a new MAC object.
# @param mac mac address as a hex numbers separated by colons
# @return A new object or undef.
sub new
{
    my ($package) = shift;

    my $data = {
        'CONFIG'         => undef,    #POS Config data
        'MAC'            => undef,    #MAC address in standard format (capital letters, ':' separated)
        'OUTMAC'         => undef,    #MAC in filename format (custom sepp)
        'POS_MACSEP_DEF' => ':',      #default MAC sepparator
        'POS_MACSEP'     => undef,    #custom MAC separator
        'POS_MACCAP'     => undef,    #MAC in capitals flag
        'MACFILTER'      => undef,    #regex filterword
        'MACPARAM'       => undef     #additional kernel parameter to add to default kernel param file
    };

    %$data = (%$data, @_);
    my $mac = 'MAC';
    if (defined $data->{'CONFIG'}) {    #full init, want to use all methods later
        _init($data);
        delete $data->{'CONFIG'};       #not needed after init
        return bless($data);
    }
    elsif (defined $data->{'MAC'}) {    #short init, only mac test, return undef if failed or object if ok
        if (!defined _parse($data)) {
            return undef;
        }
        else {
            return bless($data);
        }
    }
    else {                              #no init
        return undef;
    }

} ## end sub new


sub _init
{
    (my $self) = @_;
    #mac address suffix read filter
    my $mp = $self->{'POS_MACSEP_DEF'};
    $self->{'POS_MACCAP'}        = $self->{'CONFIG'}{'POS_MACCAP'};
    $self->{'POS_MACSEP_PREFIX'} = $self->{'CONFIG'}{'POS_MACSEP_PREFIX'};
    $mp = $self->{'CONFIG'}{'POS_MACSEP'} if defined $self->{'CONFIG'}{'POS_MACSEP'};
    $self->{'POS_MACSEP'} = $mp;
    my $filt = 'A-F';
    $filt = 'a-f' unless $self->{'POS_MACCAP'};
    $self->{'MACFILTER'} = $filt . $mp;

    my $macprefix = 'mac_separator';
    $macprefix = $self->{'CONFIG'}{'POS_MACSEP_PREFIX'} if defined $self->{'CONFIG'}{'POS_MACSEP_PREFIX'};
    my $macpar = "$macprefix=\"$self->{'POS_MACSEP'}\"";
    $macpar = '' if ($self->{'POS_MACSEP'} eq $self->{'POS_MACSEP_DEF'});
    $self->{'MACPARAM'} = $macpar;


} ## end sub _init


## @fn $ parse($mac)
# parse and verify MAC adress
# @param mac mac address as a hex numbers separated by colons
# @return verified mac or undef
sub _parse
{
    (my $self) = @_;
    my $mac_addr = $self->{'MAC'};
    my @mac_numbers = split(/:/, $mac_addr);
    if (@mac_numbers != 6) {
        return undef;
    }
    my $number = undef;
    foreach $number (@mac_numbers) {
        if (hex($number) < 0 || hex($number) > 0xff) {
            return undef;
        }
    }
    return $mac_addr;
} ## end sub _parse


#parse before convert?
#translate MAC address from filename suffix into internal representation
## @method $ outmac_to_mac( $outmac)
# Translates MAC address from file suffix representation to internal representation.
# @par Details:
# Internal representation has always uppercase letters and pairs are sepparated by ':'.
# The suffix of filename representation can be lower case with a general separator.
# Inverse to mac_to_outmac() method
# @paramaters $outmac external file suffix representation
# @return $mac internal representation of the mac address
sub outmac_to_mac
{
    my ($self, $outmac) = @_;
    my $mac = $outmac;
    my $mp  = $self->{'POS_MACSEP'};
    $mac =~ s/$mp/:/g;    # for internal purpose, always standard format
    $mac = uc($mac);
    return $mac;
} ## end sub outmac_to_mac


#parse before convert?
#translate MAC address from internal representation into filename suffix
## @method $ mac_to_outmac( $mac)
# Translates MAC address from internal representation to file suffix representation.
# @par Details:
# Internal representation has always uppercase letters and pairs are sepparated by ':'.
# The suffix of filename representation can be lower case with a general separator.
# Inverse to outmac_to_mac() method
# @paramaters $mac internal representation of the mac address
# @return $outmac external file suffix representation
sub mac_to_outmac
{
    my ($self, $mac) = @_;
    my $outmac = $mac;
    $outmac = lc($outmac) unless $self->{'POS_MACCAP'};
    my $mp = $self->{'POS_MACSEP'};
    $outmac =~ s/:/$mp/g;    # for output purpose, recreate same format as expected from the upload files
    return $outmac;
} ## end sub mac_to_outmac


#translate MAC address from internal representation into specific pxe filename
## @method $ mac_to_pxename( $mac)
# Translates MAC address from internal representation to specific, MAC based pxe filename.
# @par Details:
# Internal representation has always uppercase letters and pairs are sepparated by ':'.
# pxe file name has always lower case letters and pairs are sepparated by '-'.
# @paramaters $mac internal representation of the mac address
# @return $pxename specific pxe filename
sub mac_to_pxename
{
    my ($self, $mac) = @_;
    my $pxename = '01-' . join('-', split(/\:/, lc($mac)));    #00:22:A1:C3:DE:A1 -> 01-00-22-a1-c3-de-a1
    return $pxename;
} ## end sub mac_to_pxename

#parses macs list from hwtype and bootversion files
#uploaded by terminal to get all mac addresses as array, in internal format
sub gather_macs
{
    my ($self, $macs) = @_;
    $macs = uc($macs);
    #ignore empty values
    $macs =~ s/,+/,/g;
    $macs =~ s/^,//g;
    $macs =~ s/,$//g;
    my @macs = split(',', $macs);
    return \@macs;
} ## end sub gather_macs

## @method $ get_mac()
# return mac adress of the object
# @return mac or undef
sub get_mac
{
    my ($self) = @_;
    return $self->{'MAC'};
} ## end sub get_mac

1;
