#!/usr/bin/perl -w
############################################
# create edir definiton file 'edir.schema'
#  from hash structures
#  %LDAP_STRUCT, %LDAP_ATTR_STRUCT
#  %EDIR_STRUCT, %EDIR_ATTR_STRUCT
#  in POS::Admin::LdapStruct
############################################
use strict;
use POS::Admin::LdapStruct;

my @args  = @ARGV;
my $nargs = @args;

my $ldapobjstruct  = \%POS::Admin::LdapStruct::LDAP_STRUCT;        #explicitly refer the package source
my $ldapattrstruct = \%POS::Admin::LdapStruct::LDAP_ATTR_STRUCT;
my $edirobjstruct  = \%POS::Admin::LdapStruct::EDIR_STRUCT;        #explicitly refer the package source
my $edirattrstruct = \%POS::Admin::LdapStruct::EDIR_ATTR_STRUCT;


my $changetype_n = 'e_changetype';
my $dn_n         = 'e_dn';
my $desc_n       = 'DESC';
my $eid_n        = 'EID';
my $substr_n     = 'SUBSTR';
my $equality_n   = 'EQUALITY';
my $syntax_n     = 'SYNTAX';
my $name_n       = 'name';

my $xnds_n       = 'e_X_NDS_CONTAINMENT';
my $att_n        = 'ATT';
my $attributes_n = 'attributes';
my $must_n       = 'must';
my $may_n        = 'may';
my $sup_n        = 'e_SUP';


#compare entries by last number of OID
sub byLastId
{
    my @tmp = split('\.', $a);
    my $la = pop @tmp;
    @tmp = split('\.', $b);
    my $lb = pop @tmp;
    $la <=> $lb;
} ## end sub byLastId


print "Parsing 'LdapStruct.pm'\n\n";    #  die;


my $outputpath = $args[0];
$outputpath = '.' if (!defined $outputpath);
my $outfile = $outputpath . '/' . 'edir.schema';

#put them all together
my %cmbobjstruct  = (%$ldapobjstruct,  %$edirobjstruct);
my %cmbattrstruct = (%$ldapattrstruct, %$edirattrstruct);

my %attrstruct;
my %objstruct;
#filter out those that are not in eDir schema:
foreach my $attr (keys %cmbattrstruct) {    #reparse included hash to sort acrding to oid
    my $eid = $cmbattrstruct{$attr}{$eid_n};
    if (defined $eid) {                     #is the attribute to be defined in the eDir schema?
        $attrstruct{$eid} = $cmbattrstruct{$attr};
        $attrstruct{$eid}{$name_n} = $attr;
    }
}

foreach my $obj (keys %cmbobjstruct) {      #reparse included hash to sort acrding to oid
    my $eid = $cmbobjstruct{$obj}{$eid_n};
    if (defined $eid) {                     #is the attribute to be defined in the eDir schema?
        $objstruct{$eid} = $cmbobjstruct{$obj};
        $objstruct{$eid}{$name_n} = $obj;
    }
}


#print them
printf "Creating \'$outfile\'..\n";
if (!open(FO, ">" . $outfile)) {
    die("Can't open \'$outfile\' for write");
}

# write attributes
#
#dn: cn=schema
#changetype: modify
#add: attributetypes
#attributeTypes: ( 2.16.840.1.113719.1.453.1.1.1.1.1.120 NAME 'uidNumber'
#  DESC 'Unique ID Number for user'
#  EQUALITY integerMatch
#  SUBSTR nothere
#  SYNTAX 1.3.6.1.4.1.1466.115.121.1.27 SINGLE-VALUE )

printf "Filling attributes..\n";
my $strtmp = "###########################  Attributes imported for NLPOS ###########################\n";
printf FO $strtmp;

foreach my $eid (sort byLastId (keys %attrstruct)) {
    my $block      = "";
    my $dn         = $attrstruct{$eid}{$dn_n};
    my $changetype = $attrstruct{$eid}{$changetype_n};
    my $name       = $attrstruct{$eid}{$name_n};
    my $desc       = $attrstruct{$eid}{$desc_n};
    my $equality   = $attrstruct{$eid}{$equality_n};
    my $substr     = $attrstruct{$eid}{$substr_n};
    my $syntax     = $attrstruct{$eid}{$syntax_n};


    if ($eid =~ /.120$/) {
        $block = $block . "######################################################################################\n";
        $block = $block . "\n";
        $block =
          $block . "#########################  Attributes imported from OpenLDAP #########################\n";  #eid>120
    }


    $block = $block . "dn: $dn\n";
    $block = $block . "changetype: $changetype\n";
    $block = $block . "add: attributetypes\n";
    $block = $block . "attributeTypes: ( $eid\n";
    $block = $block . "  NAME \'$name\'\n";
    $block = $block . "  DESC \'$desc\'\n" if defined $desc;
    $block = $block . "  EQUALITY $equality\n" if defined $equality;
    $block = $block . "  SUBSTR $substr\n" if defined $substr;
    $block = $block . "  SYNTAX $syntax )\n";

    printf FO $block;
    printf FO "\n";
}


# write objects
#
#dn: cn=schema
#changetype: modify
#add: objectclasses
#objectClasses: ( 2.16.840.1.113719.1.453.2.1.2  NAME 'scService'
#  DESC 'Server as service, eg. LDAP'
#  SUP Top
#  STRUCTURAL
#  MUST ( CN $ ipHostNumber $ scDnsName $ scServiceName $ scServiceStatus  $ scServiceStartScript )
#  MAY ( scServiceEmail )
#  X-NDS_CONTAINMENT ('scBranchServer')  )
sub arrayproc
{
    (my $arrayref) = @_;
    if (defined $arrayref) {
        my $arrayline = join(' $ ', @$arrayref);
        if   ($arrayline eq "") { return (undef); }        #empty array->no array
        else                    { return ($arrayline); }
    }
    else {
        return (undef);
    }
} ## end sub arrayproc

sub arrayxndsproc
{
    (my $arrayref) = @_;
    if (defined $arrayref) {
        my $arrayline = join('\' \'', @$arrayref);
        if   ($arrayline eq "") { return (undef); }        #empty array->no array
        else                    { return ($arrayline); }
    }
    else {
        return (undef);
    }
} ## end sub arrayxndsproc


printf "Filling objects..\n";
printf FO "\n\n\n";
printf FO "######################################################################################\n";
printf FO "\n";
printf FO "\n";
printf FO "########################### Begin Class objects ######################################\n";
printf FO "#\n";
printf FO "###########################  Objects imported for NLPOS ##############################\n";


foreach my $eid (sort byLastId (keys %objstruct)) {
    my $block      = "";
    my $dn         = $objstruct{$eid}{$dn_n};
    my $changetype = $objstruct{$eid}{$changetype_n};
    my $name       = $objstruct{$eid}{$name_n};
    my $desc       = $objstruct{$eid}{$desc_n};
    my $sup        = $objstruct{$eid}{$sup_n};
    my @kind       = @{ $objstruct{$eid}{$att_n} };
    my $must       = arrayproc($objstruct{$eid}{$attributes_n}{$must_n});
    my $may        = arrayproc($objstruct{$eid}{$attributes_n}{$may_n});
    my $xnds       = arrayxndsproc($objstruct{$eid}{$xnds_n});

    if ($eid =~ /.200$/) {
        $block = $block . "######################################################################################\n";
        $block = $block . "\n";
        $block = $block . "##########################  Objects imported from OpenLDAP ###########################\n";
    }

    $block = $block . "dn: $dn\n";
    $block = $block . "changetype: $changetype\n";
    $block = $block . "add: objectclasses\n";
    $block = $block . "objectClasses: ( $eid";
    $block = $block . "\n  NAME \'$name\'";
    #printf("$name\n")  if !defined $desc;
    $block = $block . "\n  DESC \'$desc\'"                if defined $desc;
    $block = $block . "\n  SUP $sup"                      if defined $sup;
    $block = $block . "\n  @kind"                         if @kind;           #STRUCTURAL, AUXILIARY..
    $block = $block . "\n  MUST ( $must )"                if defined $must;
    $block = $block . "\n  MAY ( $may )"                  if defined $may;
    $block = $block . "\n  X-NDS_CONTAINMENT (\'$xnds\')" if defined $xnds;
    $block = $block . " )\n";
    printf FO $block;
    printf FO "\n";
}

printf "Done..\n";


