#!/usr/bin/perl -w
#######################################
# create ldap definiton files
#  from hash structures
#  %LDAP_STRUCT and %LDAP_ATTR_STRUCT
#  in POS::Admin::LdapStruct
#######################################
use strict;
use POS::Admin::LdapStruct;

my @args  = @ARGV;
my $nargs = @args;

print "Parsing 'POS::Admin::LdapStruct'\n\n";    #  die;


my $outputpath = $args[0];


$outputpath = '.' if (!defined $outputpath);
my $outfile_obj  = $outputpath . '/' . 'sc-pos-obj.schema';
my $outfile_attr = $outputpath . '/' . 'sc-pos-attr.schema';


my $objstruct  = \%POS::Admin::LdapStruct::LDAP_STRUCT;        #explicitly refer the package source
my $attrstruct = \%POS::Admin::LdapStruct::LDAP_ATTR_STRUCT;


print "Parsing 'POS::Admin::LdapStruct'\n\n";
my %objhash;                                                   #keys are OID
my %attrhash;                                                  #keys are OID
                                                               # structure :
                                                               # %objhash -> obj OID
                                                               #           -> obj NAME
                                                               #           -> obj DESC
                                                               #           -> obj MUST
                                                               #           -> obj MAY
                                                               #           -> obj ATT


#compare entries by last number of OID
sub byLastId
{
    my @tmp  = split('\.', $a);
    my $la   = pop @tmp;
    my @tmp2 = split('\.', $b);
    my $lb   = pop @tmp2;
    $la <=> $lb;
} ## end sub byLastId

foreach my $item (keys %$objstruct) {    #reparse included hash to sort acrding to oid
    my $oid = $objstruct->{$item}{'OID'};
    if (defined $oid) {                  #is the object to be defined in the pos-specific schema?
        my $desc_r = $objstruct->{$item}{'DESC'};
        my $atts_r = $objstruct->{$item}{'ATT'};
        my $must_r = $objstruct->{$item}{'attributes'}{'must'};
        my $may_r  = $objstruct->{$item}{'attributes'}{'may'};
        $objhash{$oid}{'NAME'} = $item;
        $objhash{$oid}{'DESC'} = $desc_r;
        $objhash{$oid}{'ATT'}  = $atts_r;
        $objhash{$oid}{'MUST'} = $must_r;
        $objhash{$oid}{'MAY'}  = $may_r;
    }
}

foreach my $item (keys %$attrstruct) {    #reparse included hash to sort acrding to oid
    my $oid = $attrstruct->{$item}{'OID'};
    if (defined $oid) {
        my $desc_r     = $attrstruct->{$item}{'DESC'};
        my $equality_r = $attrstruct->{$item}{'EQUALITY'};
        my $substr_r   = $attrstruct->{$item}{'SUBSTR'};
        my $syntax_r   = $attrstruct->{$item}{'SYNTAX'};
        $attrhash{$oid}{'NAME'}     = $item;
        $attrhash{$oid}{'DESC'}     = $desc_r;
        $attrhash{$oid}{'EQUALITY'} = $equality_r;
        $attrhash{$oid}{'SUBSTR'}   = $substr_r;
        $attrhash{$oid}{'SYNTAX'}   = $syntax_r;
    }
}


#save sc-pos-obj.schema
printf "Creating object definition file $outfile_obj..\n";
if (!open(FO, ">" . $outfile_obj)) {
    die("Can't writeopen $outfile_obj");
}
my $attrib;
foreach my $oid (sort byLastId (keys %objhash)) {
    my $name   = $objhash{$oid}{'NAME'};
    my $desc   = $objhash{$oid}{'DESC'};
    my $atts_r = $objhash{$oid}{'ATT'};
    my $may_r  = $objhash{$oid}{'MAY'};
    my $must_r = $objhash{$oid}{'MUST'};
    my $line   = "objectClass ( $oid  NAME \'$name\'\n";
    $line = $line . "  DESC \'$desc\'\n";
    if (defined $must_r && @$must_r) {
        my $muststr = join(' $ ', @$must_r);
        $line = $line . "  MUST ( $muststr )\n";
    }
    if (defined $may_r && @$may_r) {
        my $maystr = join(' $ ', @$may_r);
        $line = $line . "  MAY ( $maystr )\n";
    }
    if (defined $atts_r) {
        my $attstr = join(' ', @$atts_r);
        $line = $line . "  $attstr )\n";
    }
    print FO $line;
}
close(FO);


#save sc-pos-attr.schema
printf "Creating attribute definition file $outfile_attr..\n";
if (!open(FO, ">" . $outfile_attr)) {
    die("Can't writeopen $outfile_attr");
}
foreach my $oid (sort byLastId (keys %attrhash)) {
    my $name       = $attrhash{$oid}{'NAME'};
    my $desc       = $attrhash{$oid}{'DESC'};
    my $equality_r = $attrhash{$oid}{'EQUALITY'};
    my $substr_r   = $attrhash{$oid}{'SUBSTR'};
    my $syntax_r   = $attrhash{$oid}{'SYNTAX'};
    my $line       = "attributeType ( $oid\n";
    if (defined $name) {
        $line = $line . "  NAME \'$name\'\n";
    }
    if (defined $desc) {
        $line = $line . "  DESC \'$desc\'\n";
    }
    if (defined $equality_r) {
        $line = $line . "  EQUALITY $equality_r\n";
    }
    if (defined $substr_r) {
        $line = $line . "  SUBSTR $substr_r\n";
    }
    if (defined $syntax_r) {
        $line = $line . "  SYNTAX $syntax_r )\n";
    }
    print FO $line;
}
close(FO);

printf("done\n");


