#!/usr/bin/perl -w

use POS::Config;
use POS::LDAP;
use POS::posDataStatic;
use POS::posDataCache;
use POS::Syslog;
use POS::Pid;
use POS::FriendlyAdmin;
use POS::LdapControl;
use strict;

use Getopt::Long;

my $command;
my $branch;
my $id;
my @id;
my $force;
my $workstation;
my @workstation;
my $role;
my $cn;
my $hide_global = 0;
my $hide_local  = 0;
my $cr;
my $image;
my $role_desc;
my $enable;
my $disable;
my $allow_global;
my $disallow_global;
my $imagespath;
my $sincedate;
my $inlast;
my $dryrun;
my $status;
my $dn;


log_parse_argv();


my @tmp = split('/', $0);
my $appname = pop @tmp;

$command = shift @ARGV;

my $optres;

if ($appname =~ /posldap2crconfig/) {
    # posldap2crconfig compatibility mode
    if ($command eq '--dumpall' || $command eq '-d') {
        $appname = 'pos';
        $command = 'dump-all';
        $optres  = 1;
    }
    elsif ($command eq '--help' || $command eq '-h') {
        print STDERR "posldap2crconfig is now obsolete\n";
        print STDERR "    please use 'pos dump-all' instead\n\n";
        exit(0);
    }
    else {
        # without dumpall or registration update, this is supposed to do one registration cycle on hwtype files
        log_info_printf('processing HWTYPE.MAC files ');
        exit system('posleases2ldap.pl -d -o');
    }
}
elsif (!defined $command || $command eq 'help' || $command eq '-h' || $command eq '--help') {
    $command = shift @ARGV;    # let's addume the next arg is the command we want to show
    help();
}
elsif ($command eq 'id-list') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch);
}
elsif ($command eq 'id-add') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'id=s{1,}' => \@id);
    @id = (@id, @ARGV);
    @ARGV = ();
}
elsif ($command eq 'id-delete') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'id=s{1,}' => \@id, 'force' => \$force);
    @id = (@id, @ARGV);
    @ARGV = ();
}
elsif ($command eq 'id-set') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'id=s' => \$id, 'workstation=s' => \$workstation,);
}
elsif ($command eq 'cr-list') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch);
}
elsif ($command eq 'image-list') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch);
}
elsif ($command eq 'ws-list') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch);
}
elsif ($command eq 'role-list') {
    $optres = GetOptions(
        'help|h'      => \&help,
        'branch=s'    => \$branch,
        'hide-global' => \$hide_global,
        'hide-local'  => \$hide_local
    );
}
elsif ($command eq 'role-add') {
    $optres = GetOptions(
        'help|h'          => \&help,
        'branch=s'        => \$branch,
        'cash-register=s' => \$cr,
        'image=s'         => \$image,
        'role=s'          => \$role,
        'force'           => \$force,
    );
}
elsif ($command eq 'role-cr-remove') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'cash-register=s' => \$cr, 'role=s' => \$role);
}
elsif ($command eq 'role-create') {
    $optres = GetOptions(
        'help|h'        => \&help,
        'branch=s'      => \$branch,
        'role=s'        => \$role,
        'cn=s'          => \$cn,
        'description=s' => \$role_desc
    );
}
elsif ($command eq 'role-delete') {
    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'role=s' => \$role, 'force' => \$force);
}
elsif ($command eq 'role-for-ws') {
    $optres = GetOptions(
        'help|h'            => \&help,
        'branch=s'          => \$branch,
        'roles=s'           => \$role,
        'workstation=s{1,}' => \@workstation,
    );
    @workstation = (@workstation, @ARGV);
    @ARGV = ();

}
elsif ($command eq 'role-set') {
    $optres =
      GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'role=s' => \$role, 'workstation=s{1,}' => \@workstation,);
    @workstation = (@workstation, @ARGV);
    @ARGV = ();
}
elsif ($command eq 'dump-ws') {
    $optres = GetOptions('help|h' => \&help, 'workstation=s{1,}' => \@workstation);
    @workstation = (@workstation, @ARGV);
    @ARGV = ();
}
elsif ($command eq 'dump-lists') {
    $optres = GetOptions('help|h' => \&help);
}
elsif ($command eq 'dump-all') {
    $optres = GetOptions('help|h' => \&help);
}
elsif ($command eq 'remap-all') {
    $optres = GetOptions('help|h' => \&help);
}
elsif ($command eq 'sync') {
    GetOptions('help|h' => \&help);
    $optres = shift @ARGV;
}
elsif ($command eq 'role-mode') {
    $optres = GetOptions(
        'help|h'          => \&help,
        'branch=s'        => \$branch,
        'enable'          => \$enable,
        'disable'         => \$disable,
        'allow-global'    => \$allow_global,
        'disallow-global' => \$disallow_global,
        'status'          => \$status
    );
}
#elsif ($command eq 'cfg-add') {
#        $optres = GetOptions(
#       'help|h'       => \&help,
#       'branch=s'     => \$branch,
#       );
#}
elsif ($command eq 'cfg-md5') {
    $optres = GetOptions(
        'help|h'          => \&help,
        'branch=s'        => \$branch,
        'workstation=s'   => \$workstation,
        'role=s'          => \$role,
        'cash-register=s' => \$cr,
        'cn=s'            => \$cn,
        'dn=s'            => \$dn
    );
}
#elsif ($command eq 'role_refresh') {
#    $optres = GetOptions('help|h' => \&help, 'branch=s' => \$branch, 'cash-register' => \$cr);
#}
elsif ($command eq 'pxe-bootmenu') {
    $optres = GetOptions(
        'help|h'       => \&help,
        'set'          => \$enable,
        'undo'         => \$disable,
        'force'        => \$force,
        'imagespath=s' => \$imagespath,
    );
}
elsif ($command eq 'ws-remove') {
    $optres = GetOptions(
        'help|h'            => \&help,
        'workstation=s{1,}' => \@workstation,
        'no-boot-since=s'   => \$sincedate,
        'no-boot-in-last=s' => \$inlast,
        'force'             => \$force,
        'dry-run'           => \$dryrun,
    );
    @workstation = (@workstation, @ARGV);
    @ARGV = ();
}
else {
    $optres = 0;
}

sub help
{
    $command = '' unless defined $command;
    print STDERR "\n";
    if ($command eq 'id-list') {
        print STDERR "Usage:\n";
        print STDERR "  $appname id-list\n";
        print STDERR "\nDescription:\n";
        print STDERR "Print the ID list, one ID per line.\n";
    }
    elsif ($command eq 'id-add') {
        print STDERR "Usage:\n";
        print STDERR "  $appname id-add [--id] <id> [<id>]...\n";
        print STDERR "\nDescription:\n";
        print STDERR "Add a new ID.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --id                        can be omitted\n";
        print STDERR "  <id>                        new ID\n";
    }
    elsif ($command eq 'id-delete') {
        print STDERR "Usage:\n";
        print STDERR "  $appname id-delete [--id] <id> [<id>]... [--force]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Delete an ID.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --id                        can be omitted\n";
        print STDERR "  <id>                        ID from the ID list\n";
        print STDERR "  --force                     delete ID even if it is assigned\n";
    }
    elsif ($command eq 'id-set') {
        print STDERR "Usage:\n";
        print STDERR "  $appname id-set --id <id> --workstation <name or MAC>\n";
        print STDERR "\nDescription:\n";
        print STDERR "Assign an ID to given workstation.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --id <id>                   ID from the ID list\n";
        print STDERR "  --workstation <name or MAC> MAC or LDAP name of the workstation\n";
    }
    elsif ($command eq 'cr-list') {
        print STDERR "Usage:\n";
        print STDERR "  $appname cr-list\n";
        print STDERR "\nDescription:\n";
        print STDERR "List the registered Cash-Register types.\n";
    }
    elsif ($command eq 'image-list') {
        print STDERR "Usage:\n";
        print STDERR "  $appname image-list\n";
        print STDERR "\nDescription:\n";
        print STDERR "List the registered images.\n";
    }
    elsif ($command eq 'ws-list') {
        print STDERR "Usage:\n";
        print STDERR "  $appname ws-list\n";
        print STDERR "\nDescription:\n";
        print STDERR "List the registered workstations.\n";
    }
    elsif ($command eq 'role-list') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-list [--hide-local] [--hide-global]\n";
        print STDERR "\nDescription:\n";
        print STDERR "List the registered workstations.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --hide-local                hide local roles\n";
        print STDERR "  --hide-global               hide global roles\n";
    }
    elsif ($command eq 'role-add') {
        print STDERR "Usage:\n";
        print STDERR
          "  $appname role-add --cash-register <cn or hwtype> --image <image> --role <cn or name> [--force]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Copies the global Cash-Register configuration to the given role and assign the image to it.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --cash-register <cn/hwtype> identifies the source Cash-Register\n";
        print STDERR "  --image <image cn or name>  image cn or name\n";
        print STDERR "  --role <role cn or name>    role cn or name\n";
        print STDERR "  --force                     replace target Cash-Register if exists\n";
    }
    elsif ($command eq 'role-cr-remove') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-cr-remove --role <cn or name> --cash-register <cn or hwtype>\n";
        print STDERR "\nDescription:\n";
        print STDERR "Removes a copy of given Cash-Register from given role.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --role <role cn or name>    role cn or name\n";
        print STDERR "  --cash-register <cn/hwtype> identifies the source Cash-Register\n";
    }
    elsif ($command eq 'role-create') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-create --cn <cn> --role <name> --description <description>\n";
        print STDERR "\nDescription:\n";
        print STDERR "Create new role.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --cn <cn>                   LDAP cn of the new role\n";
        print STDERR "  --role <name>               role name that is shown to users\n";
        print STDERR "  --description <name>        role description that is shown to users\n";
    }
    elsif ($command eq 'role-delete') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-delete --role <role cn or name> [--force]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Delete a role.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --role <role cn or name>    role cn or name\n";
        print STDERR "  --force                     delete a non-empty role\n";
    }
    elsif ($command eq 'role-for-ws') {
        print STDERR "Usage:\n";
        print STDERR
          "  $appname role-for-ws --roles <role1>[,<role2>,...] [--workstation] <name or MAC> [<name or MAC>...]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Set the list of allowed roles for given workstation.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --roles <role cn or name>[,...]   list of role cn or names, separated by ','\n";
        print STDERR "  --workstation <name or MAC>       MAC or LDAP name of the workstation\n";
    }
    elsif ($command eq 'role-set') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-set --role <role> [--workstation] <name or MAC> [<name or MAC>...]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Assign the given role to the given workstation.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --role <role cn or name>      role cn or name\n";
        print STDERR "  --workstation <name or MAC>   MAC or LDAP name of the workstation\n";
    }
    elsif ($command eq 'dump-ws') {
        print STDERR "Usage:\n";
        print STDERR "  $appname dump-ws [--workstation] <name or MAC> [<name or MAC>...]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Writes config.MAC for the given workstation.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --workstation <name or MAC>   MAC or LDAP name of the workstation\n";
    }
    elsif ($command eq 'dump-all') {
        print STDERR "Usage:\n";
        print STDERR "  $appname dump-all\n";
        print STDERR "\nDescription:\n";
        print STDERR
"Writes role and ID lists, default pxe, and config.MAC, with specific pxe if needed, for the all workstations.\n";
    }
    elsif ($command eq 'remap-all') {
        print STDERR "Usage:\n";
        print STDERR "  $appname remap-all\n";
        print STDERR "\nDescription:\n";
        print STDERR "Updates LDAP registration (ID to DNS and IP mapping) for all workstations.\n";
    }
    elsif ($command eq 'dump-lists') {
        print STDERR "Usage:\n";
        print STDERR "  $appname dump-lists\n";
        print STDERR "\nDescription:\n";
        print STDERR "Writes role and ID lists, and refreshes the default pxe file.\n";
    }
    elsif ($command eq 'sync') {
        print STDERR "Usage:\n";
        print STDERR "  $appname sync [status|start|stop]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Provides information and control about LDAP synchronization.\n";
        print STDERR "\nOptions:\n";
        print STDERR " status\n";
        print STDERR " start\n";
        print STDERR " stop\n";
    }
    elsif ($command eq 'pxe-bootmenu') {
        print STDERR "Usage:\n";
        print STDERR "  $appname pxe-bootmenu --set [--imagespath <custom boot image directory>] [--force]\n";
        print STDERR "  $appname pxe-bootmenu --undo [--force]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Creates pxe boot menu to directly boot custom images (e.g. bios update).\n";
        print STDERR "\nOptions:\n";
        print STDERR " --set           create pxe menu\n";
        print STDERR " --undo          restore previous default and specific pxe files\n";
        print STDERR " --force         allows to overwrite backup files by current ones or vice versa\n";
        print STDERR " --imagespath    path to directory containing files to add into menu,\n";
        print STDERR "                 will be copied into 'boot/ext' subdir. If this option is\n";
        print STDERR "                 not supplied, only files currently existing in 'boot/ext'\n";
        print STDERR "                 will be used\n";
    }
    elsif ($command eq 'ws-remove') {
        print STDERR "Usage:\n";
        print STDERR "  $appname ws-remove [--workstation] <name or MAC> [<name or MAC>...]\n";
        print STDERR "  $appname ws-remove --no-boot-since <date>  [--dry-run] [--force]\n";
        print STDERR "  $appname ws-remove --no-boot-in-last <time>  [--dry-run] [--force]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Deletes workstation objects from LDAP.\n";
        print STDERR "\nOptions:\n";
        print STDERR " --workstation              cn name or MAC of workstation to delete\n";
        print STDERR " --no-boot-since <date>     delete workstations not reported online since <date>,\n";
        print STDERR "                            <date> format must be compatible with linux 'date' command\n";
        print STDERR " --no-boot-in-last <time>   delete workstations not reported online in last <time> seconds\n";
        print STDERR " --dry-run                  only show actions to be performed, and some additional info\n";
        print STDERR " --force                    forces LDAP data removal even if workstation is detected online\n";
    }
    elsif ($command eq 'role-mode') {
        print STDERR "Usage:\n";
        print STDERR "  $appname role-mode  [--enable|--disable|--allow-global|--disallow-global|--status]\n";
        print STDERR "\nDescription:\n";
        print STDERR "Set role mode.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --enable                  enables rolebased mode\n";
        print STDERR "  --disable                 disables rolebased mode\n";
        print STDERR "  --allow-global            allow global roles\n";
        print STDERR "  --disallow-global         do not allow global roles\n";
        print STDERR "  --status                  print current role mode setting\n";
    }
    elsif ($command eq 'cfg-md5') {
        print STDERR "Usage:\n";
        print STDERR "  $appname cfg-md5  --role <role cn or name> --cn <config cn>\n";
        print STDERR "  $appname cfg-md5  --role <role cn or name> --cash-register <cn or hwtype> --cn <config cn>\n";
        print STDERR "  $appname cfg-md5  --workstation <name or MAC> --cn <config cn>\n";
        print STDERR "  $appname cfg-md5  --dn <config DN>\n";
        print STDERR "\nDescription:\n";
        print STDERR "Set cfg md5 sum, for scConfigFile(Sync)Template objects located in various LDAP locations.\n";
        print STDERR "\nOptions:\n";
        print STDERR "  --role                    local role name or DN to use\n";
        print STDERR "  --cn                      name of scConfigFileTemplate to act on\n";
        print STDERR "  --cash-register           name of the cashregister to use,\n";
        print STDERR "                            must be used in conjunction with --role\n";
        print STDERR "  --workstation             workstation to use\n";
        print STDERR "  --dn                      direct DN of scConfigFileTemplate to act on\n";
    }
    else {
        usage();
    }
    exit(0);
} ## end sub help

sub usage
{
    print STDERR "Usage:\n";
    print STDERR "\n";
    print STDERR "  $appname [--global-options] <command> [--command-options] [arguments]\n";
    print STDERR "\n";
    print STDERR "\n";
    print STDERR "Global options:\n";
    print STDERR "\n";
    print STDERR "  -h, --help                  displays this help\n";
    print STDERR "  -h, --help <command>        displays help on specified command\n";
    print STDERR "  --branch <scLocation DN>    specify Branch on which the command acts,\n";
    print STDERR "                              required on Admin Server\n";
    log_print_usage();

    print STDERR "\n";
    print STDERR "Commands:\n";
    print STDERR "\n";
    print STDERR "  id-list           List all available ids in ID pool.\n";
    print STDERR "  cr-list           List all global cashregister objects.\n";
    print STDERR "  image-list        List all images, their versions and status.\n";
    print STDERR "  ws-list           List all registered workstations.\n";
    print STDERR "  role-list         List roles, local or global.\n";
    print STDERR "  id-add            Add new ID into ID pool.\n";
    print STDERR "  id-delete         Remove ID from ID pool.\n";
    print STDERR "  id-set            Assign ID to workstation.\n";
    print STDERR "  role-create       Create a new role.\n";
    print STDERR "  role-add          Add a cash register under a role.\n";
    print STDERR "  role-cr-remove    Remove cash register from a role.\n";
    print STDERR "  role-delete       Delete specified role.\n";
    print STDERR "  role-for-ws       Set allowed role(s) for given workstation(s).\n";
    print STDERR "  role-set          Assign role to a workstation.\n";
    print STDERR "  dump-ws           Recreate config.MAC for given workstation, according to the LDAP.\n";
    print STDERR "  dump-lists        Recreate globaly used data files.\n";
    print STDERR "  dump-all          Recreate all generated files according to the LDAP.\n";
    print STDERR "  remap-all         Apply current mappings to all workstations.\n";
    print STDERR "  sync              Manage synchronization service.\n";
    print STDERR "  pxe-bootmenu      Create pxe boot menu to directly boot given images.\n";
    print STDERR "  ws-remove         Remove workstation(s), by name, MAC, or last boot time.\n";
    print STDERR "  role-mode         Manage a role mode.\n";
    print STDERR "  cfg-md5           Regenerate md5sum of an associated configuration file.\n";
    print STDERR "\n";
} ## end sub usage

if (@ARGV) {
    print STDERR "Unrecognized arguments '@ARGV'\n";
    $optres = 0;
}


unless ($optres) {
    print STDERR "Error parsing parameters\n\n";
    (defined $command) ? help() : usage();
    exit(1);
}


my %POS_GLOBALS;

my $static_obj;

if (defined $branch) {
    if (!-f "/etc/SLEPOS/adminserver.conf") {
        log_error_print(" --branch can be used only on Admin Server");
        exit 1;
    }
    $static_obj = POS::posDataStatic->new('MODE' => 'admin', 'BRANCHBASE' => $branch);
#to avoid time consuming loading of entire LDAP tree into memory we find branch credentials in LDAP and use them as ADMIN
#therefor ACL rules apply on our queries, so search is limited only to relevant branch info
    my $ldap = POS::LDAP->new('CONFIG' => $static_obj->{'CONFIG'});
    return unless (defined $ldap);
    my $res =
      $ldap->search(base => $branch, scope => 'base', filter => '(objectClass=scLocation)', attrs => ['userPassword']);
    if ($res->code) {
        #some error encountered
        use Net::LDAP::Constant qw(LDAP_NO_SUCH_OBJECT);
        if ($res->code == LDAP_NO_SUCH_OBJECT) {
            log_crit_print('Entered branch does not exist. Check --branch parameter');
        }
        else {
            log_crit_printf('LDAP query returned error %s, code: %d', $res->error, $res->code);
        }
        exit(1);
    }
    elsif ($res->count != 1) {
        log_crit_print('Entered DN does not point to branch scLocation or LDAP is damaged. Check --branch parameter');
        exit(1);
    }
    $static_obj->{'CONFIG'}{'POS_ADMIN_DN'}       = $branch;
    $static_obj->{'CONFIG'}{'POS_ADMIN_PASSWORD'} = $res->pop_entry()->get_value('userPassword');
    $POS_GLOBALS{'ON_ADMIN'}                      = 1;
}
else {
    if (!-f "/etc/SLEPOS/branchserver.conf") {
        log_error_print("On Admin Server the branch should be specified with --branch");
        exit 1;
    }
    $static_obj = POS::posDataStatic->new('MODE' => 'branchadmin');
    $POS_GLOBALS{'ON_ADMIN'} = 0;
}

#init static and dynamic cache here
if (!defined $static_obj) {    #error already processed in the module
    exit(1);
}

$POS_GLOBALS{'STATIC'} = $static_obj;

my $cache_obj = POS::posDataCache->new('STATIC' => $static_obj);
if (!defined $cache_obj) {     #error already processed in the module
    exit(1);
}

$POS_GLOBALS{'CACHE'} = $cache_obj;

my $fa = new POS::FriendlyAdmin(%POS_GLOBALS);
exit 1 unless defined $fa;

my $ret;

if ($command eq 'id-list') {
    $ret = $fa->id_list();
}
elsif ($command eq 'id-add') {
    if (!@id) {
        log_error_print("Missing id");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->id_add(\@id);
    }
}
elsif ($command eq 'id-delete') {
    if (!@id) {
        log_error_print("Missing id");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->id_delete(\@id, $force);
    }
}
elsif ($command eq 'id-set') {
    if (!defined $workstation) {
        log_error_print("Missing --workstation");
        help();
        $ret = 1;
    }
    elsif (!defined $id) {
        log_error_print("Missing --id");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->id_set($id, $workstation);
    }
}
elsif ($command eq 'cr-list') {
    $ret = $fa->cr_list();
}
elsif ($command eq 'image-list') {
    $ret = $fa->image_list();
}
elsif ($command eq 'ws-list') {
    $ret = $fa->ws_list();
}
elsif ($command eq 'role-list') {
    $ret = $fa->role_list($hide_global, $hide_local);
}
elsif ($command eq 'role-add') {
    if (!defined $cr) {
        log_error_print("Missing --cash-register");
        help();
        $ret = 1;
    }
    elsif (!defined $image) {
        log_error_print("Missing --image");
        help();
        $ret = 1;
    }
    elsif (!defined $role) {
        log_error_print("Missing --role");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_add($cr, $image, $role, $force);
    }
}
elsif ($command eq 'role-cr-remove') {
    if (!defined $cr) {
        log_error_print("Missing --cash-register");
        help();
        $ret = 1;
    }
    elsif (!defined $role) {
        log_error_print("Missing --role");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_cr_remove($role, $cr);
    }
}
elsif ($command eq 'role-create') {
    if (!defined $role) {
        log_error_print("Missing --role");
        help();
        $ret = 1;
    }
    elsif (!defined $cn) {
        log_error_print("Missing --cn");
        help();
        $ret = 1;
    }
    elsif (!defined $role_desc) {
        log_error_print("Missing --description");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_create($cn, $role, $role_desc);
    }
}
elsif ($command eq 'role-delete') {
    if (!defined $role) {
        log_error_print("Missing --role");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_delete($role, $force);
    }
}
elsif ($command eq 'role-for-ws') {
    if (!@workstation) {
        log_error_print("No workstation specified");
        help();
        $ret = 1;
    }
    elsif (!defined $role) {
        log_error_print("Missing --roles");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_for_ws(\@workstation, $role);
    }
}
elsif ($command eq 'role-set') {
    if (!@workstation) {
        log_error_print("No workstation specified");
        help();
        $ret = 1;
    }
    elsif (!defined $role) {
        log_error_print("Missing --role");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->role_set(\@workstation, $role);
    }
}
elsif ($command eq 'dump-ws') {
    if (!@workstation) {
        log_error_print("No workstation specified");
        help();
        $ret = 1;
    }
    else {
        $ret = $fa->dump_ws(\@workstation);
    }
}
elsif ($command eq 'dump-lists') {
    $ret = $fa->dump_lists();
}
elsif ($command eq 'dump-all') {
    $ret = $fa->dump_all();
}
elsif ($command eq 'remap-all') {
    $ret = $fa->remap_all();
}
elsif ($command eq 'sync') {
    # is sync command valid? Only on BS, on AS or Combo is invalid
    if (-f "/etc/SLEPOS/adminserver.conf") {
        log_error_print("Synchronization management is enabled only on dedicated BranchServers");
        exit -1;
    }
    my $lctrl = POS::LdapControl->new(CONFIG => $static_obj->{'CONFIG'});
    $optres = 'status' if ($optres eq "");
    if ($optres eq 'status') {
        my $state = $lctrl->getSyncState();
        if ($state == 0) {
            print "Synchronization is running\n";
            $ret = 0;
        }
        elsif ($state == 1) {
            print "Synchronization is stopped\n";
            $ret = 0;
        }
        else {
            log_error_print("Error in communicating with LDAP server");
            $ret = -1;
        }
    }
    elsif ($optres eq 'stop') {
        my $state = $lctrl->StopSync();
        if ($state == 0) {
            print "Synchronization stopped successfuly\n";
            $ret = 0;
        }
        elsif ($state == -1) {
            log_error_print("Error in communicating with LDAP server");
            $ret = -1;
        }
        else {
            print "Synchronization stop failed\n";
            $ret = 1;
        }
    }
    elsif ($optres eq 'start') {
        my $state = $lctrl->StartSync();
        if ($state == 0) {
            print "Synchronization started successfuly\n";
            $ret = 0;
        }
        elsif ($state == -1) {
            log_error_print("Error in communicating with LDAP server");
            $ret = -1;
        }
        else {
            print "Synchronization start failed\n";
            $ret = 1;
        }
    }
    else {
        log_error_print("Invalid arguments.");
        help();
    }
}
#elsif ($command eq 'role-status') {
#}
#elsif ($command eq 'role_refresh') {
#    $ret = $fa->role_refresh($cr);
#}
elsif ($command eq 'role-mode') {
    if ($enable) {
        $ret = $fa->role_mode('scAllowRoles', 'TRUE');
    }
    elsif ($disable) {
        $ret = $fa->role_mode('scAllowRoles', 'FALSE');
    }
    elsif ($allow_global) {
        $ret = $fa->role_mode('scAllowGlobalRoles', 'TRUE');
    }
    elsif ($disallow_global) {
        $ret = $fa->role_mode('scAllowGlobalRoles', 'FALSE');
    }
    elsif ($status) {
        $ret = $fa->role_status();
    }
    else {
        log_error_print("Missing arguments.");
        help();
        $ret = 1;
    }
}
elsif ($command eq 'pxe-bootmenu') {
    if ($enable) {
        $ret = $fa->pxe_menu_set($imagespath, $force);
    }
    elsif ($disable) {
        $ret = $fa->pxe_menu_undo($force);
    }
    else {
        log_error_print("Missing --set or --undo argument");
        help();
        $ret = 1;
    }
}
elsif ($command eq 'ws-remove') {
    if (@workstation) {
        $ret = $fa->ws_remove_list(\@workstation, $force, $dryrun);
    }
    elsif ($sincedate) {
        $ret = $fa->ws_remove_bytime($sincedate, 'since', $force, $dryrun);
    }
    elsif ($inlast) {
        $ret = $fa->ws_remove_bytime($inlast, 'inlast', $force, $dryrun);
    }
    else {
        log_error_print("Missing arguments.");
        help();
        $ret = 1;
    }
}
elsif ($command eq 'cfg-md5') {
    if ($dn) {
        $ret = $fa->cfg_regenerate_md5_dn($dn);
    }
    elsif ($workstation || $role || ($role && $cr)) {
        if ($cn) {
            $ret = $fa->cfg_regenerate_md5($workstation, $role, $cr, $cn);
        }
        else {
            log_error_print("Missing config object name (--cn)");
            help();
            $ret = 1;
        }
    }
    else {
        log_error_print("Missing arguments.");
        help();
        $ret = 1;
    }
}

exit $ret;

