#!/usr/bin/perl -w

use strict;

use POS::Config;
use POS::LDAP;
use IO::File;

# check we are on admin machine (or combo)
die "ACL upgrade is valid only on machines with deployed POS AdminServer!" if (not -e "/etc/SLEPOS/adminserver.conf");

my $config = new POS::Config("/etc/SLEPOS/adminserver.conf");
my $ldap = new POS::LDAP(CONFIG => $config);
die "Connection to LDAP failed! See slapd logfile for more information." if not defined $ldap;

# ACL file header
my $header = "#STARTACL-default
access to dn.base=\"$config->{'ALL_LDAPBASE'}\"
    by users read
    by anonymous none
access to dn.subtree=\"cn=global,$config->{'ALL_LDAPBASE'}\"
    by users read
    by anonymous none
access to dn.subtree=\"cn=standards,$config->{'ALL_LDAPBASE'}\"
    by users read
    by anonymous none
access to filter=\"(objectClass=organizationalUnit)\"
    by set=\"user/-* & this\" read
    by anonymous none
#ENDACL-default\n";

# get scLocations from LDAP
my $res = $ldap->bind($config->{'POS_ADMIN_DN'}, $config->{'POS_ADMIN_PASSWORD'});
$res = $ldap->search(base => $config->{'ALL_LDAPBASE'}, scope => 'sub', filter => '(objectClass=scLocation)');
die "Error in LDAP search - " . $res->error . " - " . $res->code . "\n" if ($res->is_error());

# create rule for V scLocation
my $rules = "";
foreach my $entry ($res->entries) {
    my $dn = $entry->dn();
    $rules = $rules . "#STARTACL-$dn
access to dn.subtree=\"$dn\"
    by dn.base=\"$dn\" write
    by users none
    by anonymous auth
#ENDACL-$dn\n";
}

# get scLocations from LDAP
$res = $ldap->search(base => $config->{'ALL_LDAPBASE'}, scope => 'sub', filter => '(objectClass=scRefObjectContainer)');
die "Error in LDAP search - " . $res->error . " - " . $res->code . "\n" if ($res->is_error());

# create ruke for V scRefObjectContainer which is under orgUnit
my $refContrules = "";
foreach my $entry ($res->entries) {
    my $dn = $entry->dn();
    # get ou dn from
    my ($oudn) = $dn =~ /^cn=[^,]*,(.*)/;
    next if $oudn !~ /^ou=.*/;
    $refContrules = $refContrules . "#STARTACL-$dn
access to dn.subtree=\"$dn\"
    by dn.children=\"$oudn\" read
    by anonymous none
#ENDACL-$dn\n";
}

# backup old ACL file
my $acl       = "/etc/openldap/acl.ldif";
my $backupacl = "/etc/openldap/acl.ldif.POSsave";
if (-f $acl) {
    print "Backuping old acl.ldif file. Backup is created in $backupacl\n";
    die "[ERROR] Failed to backup old $acl! Check your permissions." if (not rename $acl, $backupacl);
}

# out to the new ACL file
my $aclhandle = new IO::File($acl, "w");
if (not defined $aclhandle) {
    if (-f $backupacl) {
        rename $backupacl, $acl;
        die "[CRIT] Cannot open file handle for new ACL file! Backup restored!";
    }
    else {
        die "[CRIT] Cannot open file handle for new ACL file!";
    }
}
print $aclhandle $header;
print $aclhandle $rules;
print $aclhandle $refContrules;
$aclhandle->close();
# clear
undef $ldap;
undef $aclhandle;
print "All done!\n";
