#!/usr/bin/perl -w

#
# Generates default pxe configuration from LDAP
# writes default pxe object to ldap if not present
#


use Getopt::Long;
#use POS::LDAP;
#use Net::DNS;
#use Net::IP;
#use Net::IPv4Addr;
#use Socket;
#use File::Path;
#use File::Copy;
#use File::Compare;
#use IO::File;
use POSIX qw(tmpnam);
#use Time::localtime;
#use URI::Escape;
use POS::Config;
use POS::Syslog;
use POS::Pid;
#use POS::LdapUtil;
#use POS::posDns;
use POS::posDataStatic;
use POS::posDataCache;

use strict;


# version  of the package

my $VERSION = 0.1;


######################
# main program
######################

log_parse_argv();

# parse command-line options
# config file options can be overwritten by command line options
if (!GetOptions() ||
    $#ARGV >= 0) {
    log_alert_print('called with invalid parameters');
    print_usage();
    exit 1;
}


#init static and dynamic cache here
my $static_obj = POS::posDataStatic->new();
if (!defined $static_obj) {    #error already processed in the module
    exit(1);
}

my $cache_obj = POS::posDataCache->new('STATIC' => $static_obj);
if (!defined $cache_obj) {     #error already processed in the module
    exit(1);
}


# check if already running
$SIG{'INT'} = 'break';
my $pid_obj = POS::Pid->new(DIRECTORY => '/var/run/', TIMEOUT => 5);
if ($pid_obj->{'ERROR'}) {
    log_alert_print('already running');
    printf("$pid_obj->{'ERROR_MSG'}\n");
    exit(1);
}

####################

# write SLEPOS defaults into LDAP
my $pxe_params  = $static_obj->{'CONFIG'}{'TFTP_DEFAULT_KERNEL_PARAMETERS'};
my $pxe_dn_base = $static_obj->{'BRANCHBASE'};
my $pxe_cn      = 'posdefaults';                                               #TODO rename??
my $pxe_dn      = 'cn=' . $pxe_cn . ',' . $pxe_dn_base;

my $res = $cache_obj->{'LDAPCACHE'}->add(
    $pxe_dn,
    attr => [
        objectClass        => ['scPxeFileTemplate', 'top'],
        cn                 => $pxe_cn,
        scMust             => 'TRUE',
        scKernelParameters => $pxe_params,
        description =>
'default SLEPOS pxe parameters, taken from TFTP_DEFAULT_KERNEL_PARAMETERS key in defaults configuration file.',
    ]
);
if ($res->code == 68) {
    log_warn_print(
"pxe with reserved name \'$pxe_cn\' already exists in LDAP under \'$pxe_dn_base\', cannot add pos default parameters."
    );
}

# reload pxe data
my $defpxe_hr = $cache_obj->{'DEFAULT_PXE'};
$cache_obj->_get_default_pxes($defpxe_hr->{'LDAP'});
$cache_obj->process_pxe($defpxe_hr->{'LDAP'});

# write default pxe
exit $cache_obj->write_pxefile($defpxe_hr);


sub print_usage
{
    print STDERR "description:\n";
    print STDERR "  a tool to create default pxefile from LDAP data (for current branchserver)\n";
    print STDERR "usage:\n";
    #TODO allow specification of ldap host and branchbase
    #TODO allow force/disable of default pxe object generation from default cfg. pos file
    log_print_usage();
} ## end sub print_usage


END {
#delete only if pid assigned (no early ctrl+c), not forked to other or if pidfile is ours and not of some other instance already runing
    $pid_obj->delete() if defined $pid_obj && $$ == $pid_obj->get_pid() && $$ == $pid_obj->get_pidf();
} ## end END

sub break
{
    #main reason is to invoke END block in the ctrl+C evend to clear the pid file
    printf("\nctrl+C detected! \n");
    exit(1);
} ## end sub break
